<?php
/**
 * The header for our theme.
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package lontano
 */

?><!DOCTYPE html>
<html <?php language_attributes(); ?>>
<head>
<meta charset="<?php bloginfo( 'charset' ); ?>">
<meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1">
<link rel="profile" href="https://gmpg.org/xfn/11">

<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>
<?php 
	$socialHeader = get_theme_mod('lontano_theme_options_socialheader', '');
	$showSearch = get_theme_mod('lontano_theme_options_showsearch', '');
	$showNews = get_theme_mod('lontano_theme_options_showflashnews', '');
?>
<div id="page" class="site">
	<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'lontano' ); ?></a>
	<div class="lontanoTop">
		<?php if($showSearch == 1): ?>
			<div class="main-search-box"><i class="fa fa-search"></i></div>
		<?php endif; ?>
		<?php if($socialHeader == 1): ?>
			<div class="main-social-box"><i class="fa fa-share-alt"></i></div>
		<?php endif; ?>
		<?php if($showNews == 1): ?>
			<?php $newsTitle = get_theme_mod('lontano_theme_options_flashnewstext', 'Flash News'); ?>
			<div class="flashNews">
				<strong><?php echo esc_html($newsTitle); ?></strong>
				<ul id="lontanoFlash">
					<?php
					$number_post = get_theme_mod('lontano_theme_options_flashnewsnumber', '5');
					$args = array( 'posts_per_page' => intval($number_post), 'post_status'=>'publish', 'post_type'=>'post', 'orderby'=>'date', 'ignore_sticky_posts' => true );
					$myposts = new WP_Query( $args );
					if ( $myposts->have_posts() ) :
					while( $myposts->have_posts() ) : $myposts->the_post();
					?>
					<li>
						<a title="<?php the_time(get_option('date_format')); ?>" href="<?php esc_url(the_permalink()); ?>"><?php echo esc_html(wp_trim_words( get_the_title(), 4 )); ?></a>
						<span class="theFlashDate"><i class="fa fa-angle-double-right spaceLeftRight"></i><?php echo esc_html(wp_trim_words( get_the_content() , 25 )); ?></span>
					</li>
					<?php endwhile; ?>
					<?php wp_reset_postdata(); ?>
					<?php endif; ?>
				</ul>
			</div><!-- .flashNews -->
		<?php endif; ?>
	</div>
	<header id="masthead" class="site-header">
		<div class="site-branding">
			<div class="lontano-table">
				<div class="lontano-brand" itemscope itemtype="http://schema.org/Organization">
					<?php
					if ( function_exists( 'the_custom_logo' ) ) {
						the_custom_logo();
					}
					if ( is_front_page() && is_home() ) : ?>
						<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
					<?php else : ?>
						<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
					<?php
					endif;
					$lontano_description = get_bloginfo( 'description', 'display' );
					if ( $lontano_description || is_customize_preview() ) : ?>
						<p class="site-description"><?php echo $lontano_description; /* WPCS: xss ok. */ ?></p>
					<?php
					endif; ?>
				</div><!-- .lontano-brand -->
			</div><!-- .lontano-table -->
		</div><!-- .site-branding -->

		<nav id="site-navigation" class="main-navigation">
			<button class="menu-toggle" aria-controls="primary-menu" aria-expanded="false"><i class="fa fa-bars spaceLeftRight"></i></button>
			<?php wp_nav_menu( array( 'theme_location' => 'primary', 'menu_id' => 'primary-menu' ) ); ?>
		</nav><!-- #site-navigation -->
	</header><!-- #masthead -->
	<?php if($showSearch == 1): ?>
		<!-- Start: Search Form -->
		<div id="search-full">
			<div class="search-container">
				<form method="get" id="search-form" action="<?php echo esc_url(home_url( '/' )); ?>">
					<label>
						<span class="screen-reader-text"><?php esc_html_e( 'Search for:', 'lontano' ); ?></span>
						<input type="search" name="s" id="search-field" placeholder="<?php esc_attr_e('Type here and hit enter...', 'lontano'); ?>">
					</label>
				</form>
			</div>
		</div>
		<!-- End: Search Form -->
	<?php endif; ?>
	<?php if($socialHeader == 1): ?>
		<div class="socialLine">
			<?php lontano_social_buttons(); ?>
		</div>
	<?php endif; ?>
	<div id="content" class="site-content">
